# sequana_minimal

**DOI:** [10.5281/zenodo.8037161](https://doi.org/10.5281/zenodo.8037161)

## Available Versions
- **Version 23.6.13**
  - [Download](https://zenodo.org/record/8037162/files/sequana_minimal_23.6.13.img)
  - **MD5:** `16446c37ef2e6fdcbef9402b49a7a663`
  - **DOI:** [10.5281/zenodo.8037162](https://doi.org/10.5281/zenodo.8037162)
  - **Size:** 315.78 MB
  - **Binaries:** 0 available

- **Version 26.3.19**
  - [Download](https://zenodo.org/record/19127803/files/sequana_minimal_26.3.19.img)
  - **MD5:** `84b1437ac190714da3dbdc96e8974741`
  - **DOI:** [10.5281/zenodo.19127803](https://doi.org/10.5281/zenodo.19127803)
  - **Size:** 324.69 MB
  - **Binaries:** 0 available

## Binaries (46 total)

```STAR minimap2 samtools bamtools bcftools bedToBam bedtools bgzip bowtie bwa intersectBed unpigz bedtools bgzip bowtie bowtie-align-l bowtie-align-s bowtie-buildlz bowtie-build-l bowtie-build-s bowtie-inspect bowtie-inspect-l bowtie-inspect-s bowtie2 bowtie2-align-l bowtie2-align-s bowtie2-build bowtie2-build-l bowtie2-build-s bowtie2-inspect bowtie2-inspect-l bowtie2-inspect-s bowtie2sam.pl bunzip2 bzip2 pbunzip2 pbzip2 coverageBed coverage_to_regions.py freebayes freebayes-parallel generate_freebayes_region_scripts.sh sambamba sortBed tabix tabix++```
